@@ -12,24 +12,12 @@
  *
  */
 
-#include "config.h"
+#include "callbacks.h"
 
-#include <glib.h>
 #include <glib/gprintf.h>
-#include <glib/gi18n.h>
-#if HAVE_GTK3 == 0
-#include <gconf/gconf.h>
-#include <gconf/gconf-client.h>
-#else
-#include <gio/gio.h>
-#endif
-#include <gtk/gtk.h>
-#include <libmtp.h>
-#include <id3tag.h>
 #include <stdlib.h>
 
 #include "main.h"
-#include "callbacks.h"
 #include "interface.h"
 #include "mtp.h"
 #include "prefs.h"
@@ -41,12 +29,9 @@
 #include "playlist.h"
 #include "formatdevice.h"
 
-/**
- * on_quit1_activate - Call back for Quit toolbar and menu option.
- * @param menuitem
- * @param user_data
- */
 void on_quit1_activate(GtkMenuItem *menuitem, gpointer user_data) {
+    UNUSED(menuitem);
+    UNUSED(user_data);
     // Disconnect device.
     if (DeviceMgr.deviceConnected == TRUE) {
         on_deviceConnect_activate(NULL, NULL);
@@ -61,37 +46,25 @@ void on_quit1_activate(GtkMenuItem *menuitem, gpointer user_data) {
 
 // ************************************************************************************************
 
-/**
- * on_about1_activate - Call back for displaying the About Dialog Box
- * @param menuitem
- * @param user_data
- */
 void on_about1_activate(GtkMenuItem *menuitem, gpointer user_data) {
+    UNUSED(menuitem);
+    UNUSED(user_data);
     displayAbout();
 } // end on_about1_activate()
 
-
-
 // ************************************************************************************************
 
-/**
- * on_deviceRescan_activate - Callback to rescan the device properties and update the main
- * application window.
- * @param menuitem
- * @param user_data
- */
 void on_deviceRescan_activate(GtkMenuItem *menuitem, gpointer user_data) {
+    UNUSED(menuitem);
+    UNUSED(user_data);
     deviceRescan();
 } // end on_deviceRescan_activate()
 
 // ************************************************************************************************
 
-/**
- * on_filesAdd_activate - Callback to initiate an Add Files operation.
- * @param menuitem
- * @param user_data
- */
 void on_filesAdd_activate(GtkMenuItem *menuitem, gpointer user_data) {
+    UNUSED(menuitem);
+    UNUSED(user_data);
     GSList* files;
     int64_t targetFol = 0;
     //uint32_t tmpFolderID = 0;
@@ -110,10 +83,10 @@ void on_filesAdd_activate(GtkMenuItem *menuitem, gpointer user_data) {
         currentFolderID = (uint32_t) targetFol;
     }
     AlbumErrorIgnore = FALSE;
-    if (files != NULL){
-	displayProgressBar(_("File Upload"));
+    if (files != NULL) {
+        displayProgressBar(_("File Upload"));
         g_slist_foreach(files, (GFunc) __filesAdd, NULL);
-	destroyProgressBar();
+        destroyProgressBar();
     }
 
     // Now clear the GList;
@@ -132,13 +105,9 @@ void on_filesAdd_activate(GtkMenuItem *menuitem, gpointer user_data) {
 
 // ************************************************************************************************
 
-/**
- * Callback to handle the Rename Device menu option.
- * @param menuitem
- * @param user_data
- */
 void on_fileRenameFile_activate(GtkMenuItem *menuitem, gpointer user_data) {
-
+    UNUSED(menuitem);
+    UNUSED(user_data);
     GtkTreePath *path;
     GtkTreeIter iter;
     gchar *newfilename = NULL;
@@ -168,6 +137,8 @@ void on_fileRenameFile_activate(GtkMenuItem *menuitem, gpointer user_data) {
     gtk_tree_model_get(GTK_TREE_MODEL(fileList), &iter, COL_FILENAME_ACTUAL, &filename, COL_ISFOLDER, &isFolder,
             COL_FILEID, &ObjectID, -1);
 
+    gtk_tree_path_free(path);
+    
     // Make sure we are not attempting to edit the parent link folder.
     if (g_ascii_strcasecmp(filename, "..") == 0) {
         g_fprintf(stderr, _("Unable to rename parent folder\n"));
@@ -187,12 +158,9 @@ void on_fileRenameFile_activate(GtkMenuItem *menuitem, gpointer user_data) {
 
 // ************************************************************************************************
 
-/**
- * Callback to handle the Move File menu option.
- * @param menuitem
- * @param user_data
- */
 void on_fileMoveFile_activate(GtkMenuItem *menuitem, gpointer user_data) {
+    UNUSED(menuitem);
+    UNUSED(user_data);
     GList *List = NULL;
     int64_t targetfolder = 0;
 
@@ -229,16 +197,11 @@ void on_fileMoveFile_activate(GtkMenuItem *menuitem, gpointer user_data) {
     deviceRescan();
 }
 
-
 // ************************************************************************************************
 
-/**
- * on_filesDelete_activate - Callback to initiate a Delete Files operation.
- * @param menuitem
- * @param user_data
- */
 void on_filesDelete_activate(GtkMenuItem *menuitem, gpointer user_data) {
-    GtkWidget *dialog;
+    UNUSED(menuitem);
+    UNUSED(user_data);
 
     // Let's check to see if we have anything selected in our treeview?
     if (fileListGetSelection() == NULL) {
@@ -255,7 +218,7 @@ void on_filesDelete_activate(GtkMenuItem *menuitem, gpointer user_data) {
         // Now download the actual file from the MTP device.
         fileListRemove(fileListGetSelection());
     } else {
-        dialog = gtk_message_dialog_new(GTK_WINDOW(windowMain),
+        GtkWidget *dialog = gtk_message_dialog_new(GTK_WINDOW(windowMain),
                 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                 GTK_MESSAGE_WARNING,
                 GTK_BUTTONS_YES_NO,
@@ -274,15 +237,12 @@ void on_filesDelete_activate(GtkMenuItem *menuitem, gpointer user_data) {
 
 // ************************************************************************************************
 
-/**
- * on_filesDownload_activate - Callback to initiate a download files operation.
- * @param menuitem
- * @param user_data
- */
 void on_filesDownload_activate(GtkMenuItem *menuitem, gpointer user_data) {
-    int64_t targetfolder = 0;
+    UNUSED(menuitem);
+    UNUSED(user_data);
     // Let's check to see if we have anything selected in our treeview?
     if (fileListGetSelection() == NULL) {
+        int64_t targetfolder = 0;
         if ((targetfolder = folderListGetSelection()) != -1) {
             displayProgressBar(_("File download"));
             folderListDownload(folderListGetSelectionName(), targetfolder);
@@ -301,15 +261,10 @@ void on_filesDownload_activate(GtkMenuItem *menuitem, gpointer user_data) {
 
 // ************************************************************************************************
 
-/**
- * on_deviceConnect_activate - Callback used to connect a device to the application.
- * @param menuitem
- * @param user_data
- */
 void on_deviceConnect_activate(GtkMenuItem *menuitem, gpointer user_data) {
-    gchar *tmp_string;
+    UNUSED(menuitem);
+    UNUSED(user_data);
     GtkWidget *menuText;
-
     deviceConnect();
     //g_printf("Device connect/disconnect code = %d\n", result);
     // Update our label to indicate current condition.
@@ -320,7 +275,7 @@ void on_deviceConnect_activate(GtkMenuItem *menuitem, gpointer user_data) {
 
         // Update the toolbar to show a disconnect string.
         gtk_tool_button_set_label(GTK_TOOL_BUTTON(toolbuttonConnect), _("Disconnect"));
-
+        gchar *tmp_string;
         // Now update the status bar;
         if (DeviceMgr.storagedeviceID == MTP_DEVICE_SINGLE_STORAGE) {
             tmp_string = g_strdup_printf(_("Connected to %s - %d MB free"), DeviceMgr.devicename->str,
@@ -379,15 +334,9 @@ void on_deviceConnect_activate(GtkMenuItem *menuitem, gpointer user_data) {
 
 // ************************************************************************************************
 
-/**
- * Callback to handle double click on item in main window. If it's a folder, then change to it,
- * other attempt to download the file(s).
- * @param treeview
- * @param path
- * @param column
- * @param data
- */
 void fileListRowActivated(GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *column, gpointer data) {
+    UNUSED(column);
+    UNUSED(data);
     GtkTreeModel *model;
     GtkTreeModel *sortmodel;
     GtkTreeIter iter;
@@ -396,21 +345,19 @@ void fileListRowActivated(GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewC
     gboolean isFolder;
     uint32_t objectID;
 
-    GtkWidget *FileDialog;
-    gchar *savepath = NULL;
-
     // Obtain the iter, and the related objectID.
     sortmodel = gtk_tree_view_get_model(treeview);
     model = gtk_tree_model_sort_get_model(GTK_TREE_MODEL_SORT(sortmodel));
-    if (gtk_tree_model_get_iter(model, &iter, gtk_tree_model_sort_convert_path_to_child_path(GTK_TREE_MODEL_SORT(sortmodel), path))) {
+    GtkTreePath * treepath = gtk_tree_model_sort_convert_path_to_child_path(GTK_TREE_MODEL_SORT(sortmodel), path);
+    if (gtk_tree_model_get_iter(model, &iter, treepath)) {
         gtk_tree_model_get(GTK_TREE_MODEL(fileList), &iter, COL_ISFOLDER, &isFolder, COL_FILENAME_ACTUAL, &filename, COL_FILEID, &objectID, -1);
         if (isFolder == FALSE) {
             // Now download the actual file from the MTP device.
             displayProgressBar(_("File download"));
-            savepath = g_malloc0(8192);
+            gchar *savepath = g_malloc0(8192);
             // Let's confirm our download path.
             if (Preferences.ask_download_path == TRUE) {
-                FileDialog = gtk_file_chooser_dialog_new(_("Select Path to Download"),
+                GtkWidget *FileDialog = gtk_file_chooser_dialog_new(_("Select Path to Download"),
                         GTK_WINDOW(windowMain), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
                         _("_Cancel"), GTK_RESPONSE_CANCEL,
                         _("_Open"), GTK_RESPONSE_ACCEPT,
@@ -457,20 +404,17 @@ void fileListRowActivated(GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewC
             on_editFindClose_activate(NULL, NULL);
         }
     }
+    if(treepath != NULL){
+        gtk_tree_path_free(treepath);
+    }
     g_free(filename);
 } // end fileListRowActivated()
 
-
 // ************************************************************************************************
 
-/**
- * Callback to handle double click on item in folder main window.
- * @param treeview
- * @param path
- * @param column
- * @param data
- */
 void folderListRowActivated(GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *column, gpointer data) {
+    UNUSED(column);
+    UNUSED(data);
     GtkTreeModel *model;
     GtkTreeModel *sortmodel;
     GtkTreeIter iter;
@@ -488,15 +432,11 @@ void folderListRowActivated(GtkTreeView *treeview, GtkTreePath *path, GtkTreeVie
     }
 } // end folderListRowActivated()
 
-
 // ************************************************************************************************
 
-/**
- * Callback to handle selecting NewFolder from menu or toolbar.
- * @param menuitem
- * @param user_data
- */
 void on_fileNewFolder_activate(GtkMenuItem *menuitem, gpointer user_data) {
+    UNUSED(menuitem);
+    UNUSED(user_data);
     gchar *foldername = NULL;
     if (folderListGetSelection() != -1) {
         on_folderNewFolder_activate(menuitem, user_data);
@@ -512,17 +452,12 @@ void on_fileNewFolder_activate(GtkMenuItem *menuitem, gpointer user_data) {
     }
 } // end on_fileNewFolder_activate()
 
-
 // ************************************************************************************************
 
-/**
- * Callback to handle selecting NewFolder from menu or toolbar.
- * @param menuitem
- * @param user_data
- */
 void on_folderNewFolder_activate(GtkMenuItem *menuitem, gpointer user_data) {
+    UNUSED(menuitem);
+    UNUSED(user_data);
     gchar *foldername = NULL;
-    uint32_t tmpFolderID = 0;
     // Get the folder name by displaying a dialog.
     foldername = displayFolderNewDialog();
     if (foldername != NULL) {
@@ -533,7 +468,7 @@ void on_folderNewFolder_activate(GtkMenuItem *menuitem, gpointer user_data) {
             folderAdd(foldername);
         } else {
             // We have selected a folder in the folder view, so let's get it's ID.
-            tmpFolderID = currentFolderID;
+            uint32_t tmpFolderID = currentFolderID;
             currentFolderID = folderListGetSelection();
             folderAdd(foldername);
             currentFolderID = tmpFolderID;
@@ -546,13 +481,9 @@ void on_folderNewFolder_activate(GtkMenuItem *menuitem, gpointer user_data) {
 
 // ************************************************************************************************
 
-/**
- * Callback to handle selecting RemoveFolder from menu or toolbar.
- * @param menuitem
- * @param user_data
- */
 void on_folderRemoveFolder_activate(GtkMenuItem *menuitem, gpointer user_data) {
-    GtkWidget *dialog;
+    UNUSED(menuitem);
+    UNUSED(user_data);
     GtkTreeModel *sortmodel;
     GtkTreeIter iter;
     GtkTreeIter childiter;
@@ -576,7 +507,7 @@ void on_folderRemoveFolder_activate(GtkMenuItem *menuitem, gpointer user_data) {
             // Now download the actual file from the MTP device.
             folderDelete(getCurrentFolderPtr(deviceFolders, objectID), 0);
         } else {
-            dialog = gtk_message_dialog_new(GTK_WINDOW(windowMain),
+            GtkWidget *dialog = gtk_message_dialog_new(GTK_WINDOW(windowMain),
                     GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                     GTK_MESSAGE_WARNING,
                     GTK_BUTTONS_YES_NO,
@@ -593,25 +524,16 @@ void on_folderRemoveFolder_activate(GtkMenuItem *menuitem, gpointer user_data) {
     deviceRescan();
 } // end on_folderRemoveFolder_activate()
 
-
 // ************************************************************************************************
 
-/**
- * Callback to handle selecting MoveFolder from context menu.
- * @param menuitem
- * @param user_data
- */
 void on_folderMoveFolder_activate(GtkMenuItem *menuitem, gpointer user_data) {
+    UNUSED(menuitem);
+    UNUSED(user_data);
     GtkTreeModel *sortmodel;
     GtkTreeIter iter;
     GtkTreeIter childiter;
-    int64_t targetfolder = 0;
     uint32_t objectID;
 
-    LIBMTP_folder_t *currentFolder = NULL;
-    LIBMTP_folder_t *newFolder = NULL;
-    int error;
-
     // Let's see if we have anything selected in the folder view, and if not let the user know, and return
     if (gtk_tree_selection_count_selected_rows(folderSelection) == 0) {
         // Add in folder to MTP device.
@@ -625,7 +547,7 @@ void on_folderMoveFolder_activate(GtkMenuItem *menuitem, gpointer user_data) {
         gtk_tree_model_get(GTK_TREE_MODEL(folderList), &childiter, COL_FOL_ID, &objectID, -1);
 
         // Prompt for the target folder location.
-        targetfolder = getTargetFolderLocation();
+        int64_t targetfolder = getTargetFolderLocation();
         if (targetfolder == -1) {
             // If the user didn't select a folder, or the target folder is the current selected folder
             // then do nothing.
@@ -642,7 +564,7 @@ void on_folderMoveFolder_activate(GtkMenuItem *menuitem, gpointer user_data) {
         }
         // We have the target folder, so let's check to ensure that we will not create a circular
         // reference by moving a folder underneath it self.
-        currentFolder = getCurrentFolderPtr(deviceFolders, objectID);
+        LIBMTP_folder_t *currentFolder = getCurrentFolderPtr(deviceFolders, objectID);
         if (currentFolder == NULL) {
             // WTF?
             g_fprintf(stderr, "File Move Error: Can't get current folder pointer\n");
@@ -650,9 +572,10 @@ void on_folderMoveFolder_activate(GtkMenuItem *menuitem, gpointer user_data) {
         }
         // Use currentFolder as the starting point, and simply attempt to get the ptr to the new
         // folder based on this point.
-        newFolder = getCurrentFolderPtr(currentFolder->child, fileMoveTargetFolder);
+        LIBMTP_folder_t *newFolder = getCurrentFolderPtr(currentFolder->child, fileMoveTargetFolder);
         if (newFolder == NULL) {
             // We are alright to proceed.
+            int error;
             if ((error = setNewParentFolderID(objectID, fileMoveTargetFolder)) != 0) {
                 displayError(_("Unable to move the selected folder?\n"));
                 g_fprintf(stderr, "File Move Error: %d\n", error);
@@ -669,16 +592,11 @@ void on_folderMoveFolder_activate(GtkMenuItem *menuitem, gpointer user_data) {
     deviceRescan();
 } // end on_folderMoveFolder_activate()
 
-
 // ************************************************************************************************
 
-/**
- * Callback to handle selecting Rename Folder from menu
- * @param menuitem
- * @param user_data
- */
 void on_folderRenameFolder_activate(GtkMenuItem *menuitem, gpointer user_data) {
-    gchar *newfilename = NULL;
+    UNUSED(menuitem);
+    UNUSED(user_data);
     gchar *filename = NULL;
     GtkTreeModel *sortmodel;
     GtkTreeIter iter;
@@ -700,7 +618,7 @@ void on_folderRenameFolder_activate(GtkMenuItem *menuitem, gpointer user_data) {
                 COL_FOL_NAME_HIDDEN, &filename, -1);
 
         // Get our new folder name.
-        newfilename = displayRenameFileDialog(filename);
+        gchar *newfilename = displayRenameFileDialog(filename);
 
         // If the user supplied something, then update the name of the device.
         if (newfilename != NULL) {
@@ -711,16 +629,11 @@ void on_folderRenameFolder_activate(GtkMenuItem *menuitem, gpointer user_data) {
     }
 } // end on_folderRenameFolder_activate()
 
-
 // ************************************************************************************************
 
-/**
- * Callback handle to handle deleting a folder menu option.
- * @param menuitem
- * @param user_data
- */
 void on_fileRemoveFolder_activate(GtkMenuItem *menuitem, gpointer user_data) {
-    GtkWidget *dialog;
+    UNUSED(menuitem);
+    UNUSED(user_data);
 
     // Let's check to see if we have anything selected in our treeview?
     if (fileListGetSelection() == NULL) {
@@ -737,7 +650,7 @@ void on_fileRemoveFolder_activate(GtkMenuItem *menuitem, gpointer user_data) {
         // Now download the actual file from the MTP device.
         folderListRemove(fileListGetSelection());
     } else {
-        dialog = gtk_message_dialog_new(GTK_WINDOW(windowMain),
+        GtkWidget *dialog = gtk_message_dialog_new(GTK_WINDOW(windowMain),
                 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                 GTK_MESSAGE_WARNING,
                 GTK_BUTTONS_YES_NO,
@@ -752,14 +665,10 @@ void on_fileRemoveFolder_activate(GtkMenuItem *menuitem, gpointer user_data) {
 
 // ************************************************************************************************
 
-/**
- * Callback to handle the Rename Device menu option.
- * @param menuitem
- * @param user_data
- */
 void on_editDeviceName_activate(GtkMenuItem *menuitem, gpointer user_data) {
+    UNUSED(menuitem);
+    UNUSED(user_data);
     gchar *devicename = NULL;
-    gchar *tmp_string = NULL;
 
     // Get our new device name.
     devicename = displayChangeDeviceNameDialog(DeviceMgr.devicename->str);
@@ -770,7 +679,8 @@ void on_editDeviceName_activate(GtkMenuItem *menuitem, gpointer user_data) {
         setDeviceName(devicename);
         g_free(devicename);
         // Attempt to read it back as confirmation that something may of happened.
-        tmp_string = LIBMTP_Get_Friendlyname(DeviceMgr.device);
+        gchar *tmp_string = LIBMTP_Get_Friendlyname(DeviceMgr.device);
+        if (DeviceMgr.devicename != NULL) g_string_free(DeviceMgr.devicename, TRUE);
         if (tmp_string == NULL) {
             DeviceMgr.devicename = g_string_new(_("N/A"));
         } else {
@@ -782,18 +692,13 @@ void on_editDeviceName_activate(GtkMenuItem *menuitem, gpointer user_data) {
     }
 } // end on_editDeviceName_activate()
 
-
 // ************************************************************************************************
 
-/**
- * Callback to handle the displaying of the context menu.
- * @param widget
- * @param event
- * @return
- */
 gboolean on_windowMainContextMenu_activate(GtkWidget *widget, GdkEvent *event) {
+    UNUSED(widget);
+    UNUSED(event);
     GtkMenu *menu;
-    GdkEventButton *event_button;
+
     g_return_val_if_fail(widget != NULL, FALSE);
     g_return_val_if_fail(GTK_IS_MENU(widget), FALSE);
     g_return_val_if_fail(event != NULL, FALSE);
@@ -803,7 +708,7 @@ gboolean on_windowMainContextMenu_activate(GtkWidget *widget, GdkEvent *event) {
      */
     menu = GTK_MENU(widget);
     if (event->type == GDK_BUTTON_PRESS) {
-        event_button = (GdkEventButton *) event;
+        GdkEventButton *event_button = (GdkEventButton *) event;
         if (event_button->button == 3) {
             gtk_menu_popup(menu, NULL, NULL, NULL, NULL,
                     event_button->button, event_button->time);
@@ -816,15 +721,10 @@ gboolean on_windowMainContextMenu_activate(GtkWidget *widget, GdkEvent *event) {
 
 // ************************************************************************************************
 
-/**
- * Callback to handle the displaying of the context menu.
- * @param widget
- * @param event
- * @return
- */
 gboolean on_windowViewContextMenu_activate(GtkWidget *widget, GdkEvent *event) {
+    UNUSED(widget);
+    UNUSED(event);
     GtkMenu *menu;
-    GdkEventButton *event_button;
     g_return_val_if_fail(event != NULL, FALSE);
 
     /* The "widget" is the menu that was supplied when
@@ -832,7 +732,7 @@ gboolean on_windowViewContextMenu_activate(GtkWidget *widget, GdkEvent *event) {
      */
     menu = GTK_MENU(contextMenuColumn);
     if (event->type == GDK_BUTTON_PRESS) {
-        event_button = (GdkEventButton *) event;
+        GdkEventButton *event_button = (GdkEventButton *) event;
         if (event_button->button == 3) {
             gtk_menu_popup(menu, NULL, NULL, NULL, NULL,
                     event_button->button, event_button->time);
@@ -844,12 +744,9 @@ gboolean on_windowViewContextMenu_activate(GtkWidget *widget, GdkEvent *event) {
 
 // ************************************************************************************************
 
-/**
- * Callback to handle the Find menu option.
- * @param menuitem
- * @param user_data
- */
 void on_editFind_activate(GtkMenuItem *menuitem, gpointer user_data) {
+    UNUSED(menuitem);
+    UNUSED(user_data);
     if (inFindMode == FALSE) {
 
         gtk_widget_show(findToolbar);
@@ -881,23 +778,17 @@ void on_editFind_activate(GtkMenuItem *menuitem, gpointer user_data) {
 
 // ************************************************************************************************
 
-/**
- * Callback to handle the Find menu option.
- * @param menuitem
- * @param user_data
- */
 void on_editSelectAll_activate(GtkMenuItem *menuitem, gpointer user_data) {
+    UNUSED(menuitem);
+    UNUSED(user_data);
     fileListSelectAll();
 } // end on_editSelectAll_activate()
 
 // ************************************************************************************************
 
-/**
- * Callback to handle the Find toolbar close option.
- * @param menuitem
- * @param user_data
- */
 void on_editFindClose_activate(GtkMenuItem *menuitem, gpointer user_data) {
+    UNUSED(menuitem);
+    UNUSED(user_data);
     gchar* tmp_string;
 
     gtk_widget_hide(findToolbar);
@@ -954,15 +845,11 @@ void on_editFindClose_activate(GtkMenuItem *menuitem, gpointer user_data) {
 
 } // end on_editFindClose_activate()
 
-
 // ************************************************************************************************
 
-/**
- * Callback to handle the actual searching of files/folders.
- * @param menuitem
- * @param user_data
- */
 void on_editFindSearch_activate(GtkMenuItem *menuitem, gpointer user_data) {
+    UNUSED(menuitem);
+    UNUSED(user_data);
     gchar *searchstring = NULL;
     gboolean searchfiles = FALSE;
     gboolean searchmeta = FALSE;
@@ -980,7 +867,7 @@ void on_editFindSearch_activate(GtkMenuItem *menuitem, gpointer user_data) {
     searchfiles = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(FindToolbar_checkbutton_FindFiles));
     searchmeta = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(FindToolbar_checkbutton_TrackInformation));
     // disable search metadata if treatallmediaasfiles or in alternate access mode is set.
-    if(Preferences.allmediaasfiles == TRUE || Preferences.use_alt_access_method == TRUE){
+    if (Preferences.allmediaasfiles == TRUE || Preferences.use_alt_access_method == TRUE) {
         searchmeta = FALSE;
     }
     // Let's start our search.
@@ -991,20 +878,10 @@ void on_editFindSearch_activate(GtkMenuItem *menuitem, gpointer user_data) {
     g_free(searchstring);
 } // end on_editFindSearch_activate()
 
-
-
-
-
-
-
 // ************************************************************************************************
 
-/**
- * Callback to handle the change of columns viewable in the main window.
- * @param menuitem
- * @param user_data
- */
 void on_view_activate(GtkMenuItem *menuitem, gpointer user_data) {
+    UNUSED(user_data);
 #if HAVE_GTK3 == 0
     gchar *gconf_path = NULL;
     gboolean state = gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem));
@@ -1069,15 +946,11 @@ void on_view_activate(GtkMenuItem *menuitem, gpointer user_data) {
 #endif
 } // end on_view_activate()
 
-
 // ************************************************************************************************
 
-/**
- * Callback to handle user asking to create a new playlist from the AutoAddTrack to Playlist option.
- * @param button
- * @param user_data
- */
 void on_TrackPlaylist_NewPlaylistButton_activate(GtkWidget *button, gpointer user_data) {
+    UNUSED(button);
+    UNUSED(user_data);
     gchar *playlistname = NULL;
     gint combobox_entries = 0;
 
@@ -1090,9 +963,10 @@ void on_TrackPlaylist_NewPlaylistButton_activate(GtkWidget *button, gpointer use
 
         // Add it to our combobox
 #if HAVE_GTK3 == 0
-        gtk_combo_box_append_text(GTK_COMBO_BOX(combobox_AddTrackPlaylist), g_strdup(playlistname));
+        gtk_combo_box_append_text(GTK_COMBO_BOX(combobox_AddTrackPlaylist), (playlistname));
 #else
-        gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combobox_AddTrackPlaylist), g_strdup(playlistname));
+        //gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combobox_AddTrackPlaylist), g_strdup(playlistname));
+        gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combobox_AddTrackPlaylist), (playlistname));
 #endif
         g_free(playlistname);
 
@@ -1102,15 +976,10 @@ void on_TrackPlaylist_NewPlaylistButton_activate(GtkWidget *button, gpointer use
     }
 }
 
-
 // ************************************************************************************************
 
-/**
- * Callback to handle when a row is selected in the folder list.
- * @param treeselection
- * @param user_data
- */
 void on_treeviewFolders_rowactivated(GtkTreeSelection *treeselection, gpointer user_data) {
+    UNUSED(user_data);
     // Block the handler from running ...
     g_signal_handler_block((gpointer) fileSelection, fileSelectHandler);
     g_signal_handler_block((gpointer) folderSelection, folderSelectHandler);
