@@ -18,16 +18,31 @@
 #ifdef  __cplusplus
 extern "C" {
 #endif
-
-#include <gtk/gtk.h>
-
-    // Widget for formatDevice progress bar.
-    GtkWidget* create_windowFormat(void);
     
-    // Main menu callback
-    void on_editFormatDevice_activate(GtkMenuItem *menuitem, gpointer user_data);
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif    
 
-    // Format Device Progress Bar.
+#include <glib.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
+
+    /**
+     * Creates the Format Device Dialog box
+     * @return Widget of completed dialog box.
+     */
+    GtkWidget* create_windowFormat(void);
+
+    /**
+     * Callback to format the current storage device.
+     * @param menuitem
+     * @param user_data
+     */
+    void on_editFormatDevice_activate(GtkWidget *item, gpointer user_data);
+
+    /**
+     * Worker thread for on_editFormatDevice_activate();
+     */
     void formatDevice_thread(void);
 
 #ifdef  __cplusplus
