@@ -11,34 +11,11 @@
  *   file 'COPYING' located in the root directory
  *
  */
-
-#include "config.h"
-
-#include <glib.h>
-#include <glib/gprintf.h>
-#include <glib/gi18n.h>
-#if HAVE_GTK3 == 0
-#include <gconf/gconf.h>
-#include <gconf/gconf-client.h>
-#else
-#include <gio/gio.h>
-#endif
-#include <gtk/gtk.h>
-#include <libmtp.h>
-#include <id3tag.h>
-#include <stdlib.h>
-
-#include "main.h"
-#include "callbacks.h"
-#include "interface.h"
-#include "mtp.h"
-#include "prefs.h"
-#include "dnd.h"
-#include "about.h"
-#include "progress.h"
-#include "properties.h"
-#include "preferences.h"
 #include "playlist.h"
+#include "main.h"
+#include "mtp.h"
+#include "interface.h"
+#include "callbacks.h"
 
 GtkWidget *windowPlaylistDialog;
 // Playlist
@@ -72,10 +49,6 @@ GtkWidget *button_Add_Files;
 
 // Playlist support
 
-/**
- * Create the Playlist Editor Window.
- * @return
- */
 GtkWidget* create_windowPlaylist(void) {
     GtkWidget *window_playlist;
     GtkWidget *vbox1;
@@ -84,12 +57,12 @@ GtkWidget* create_windowPlaylist(void) {
 
     GtkWidget *button_Add_Playlist;
     GtkWidget *button_Import_Playlist;
-    GtkWidget *alignment2;
+    //GtkWidget *alignment2;
     GtkWidget *hbox3;
     GtkWidget *image2;
     GtkWidget *label3;
 
-    GtkWidget *alignment1;
+    //GtkWidget *alignment1;
     GtkWidget *hbox2;
     GtkWidget *image1;
     GtkWidget *label2;
@@ -98,12 +71,12 @@ GtkWidget* create_windowPlaylist(void) {
 
     GtkWidget *vbuttonbox1;
 
-    GtkWidget *alignment6;
+    // GtkWidget *alignment6;
     GtkWidget *hbox8;
     GtkWidget *image6;
     GtkWidget *label10;
 
-    GtkWidget *alignment7;
+    //GtkWidget *alignment7;
     GtkWidget *hbox9;
     GtkWidget *image7;
     GtkWidget *label11;
@@ -131,6 +104,7 @@ GtkWidget* create_windowPlaylist(void) {
     gtk_window_set_position(GTK_WINDOW(window_playlist), GTK_WIN_POS_CENTER_ON_PARENT);
     gtk_window_set_skip_taskbar_hint(GTK_WINDOW(window_playlist), TRUE);
     gtk_window_set_type_hint(GTK_WINDOW(window_playlist), GDK_WINDOW_TYPE_HINT_DIALOG);
+    gtk_container_set_border_width(GTK_CONTAINER(window_playlist), 5);
     g_free(winTitle);
 #if HAVE_GTK3 == 0
     vbox1 = gtk_vbox_new(FALSE, 0);
@@ -150,7 +124,17 @@ GtkWidget* create_windowPlaylist(void) {
     label_Playlist = gtk_label_new(_("Current Playlist: "));
     gtk_widget_show(label_Playlist);
     gtk_box_pack_start(GTK_BOX(hbox1), label_Playlist, FALSE, FALSE, 5);
+#if HAVE_GTK3 == 0    
     gtk_misc_set_padding(GTK_MISC(label_Playlist), 5, 0);
+#else
+#if GTK_CHECK_VERSION(3,12,0)
+    gtk_widget_set_margin_start(label_Playlist, 5);
+    gtk_widget_set_margin_end(label_Playlist, 5);
+#else
+    gtk_widget_set_margin_left(label_Playlist, 5);
+    gtk_widget_set_margin_right(label_Playlist, 5);
+#endif
+#endif    
 
 #if HAVE_GTK3 == 0
     comboboxentry_playlist = gtk_combo_box_new_text();
@@ -171,16 +155,16 @@ GtkWidget* create_windowPlaylist(void) {
     gtk_widget_set_tooltip_text(button_Add_Playlist, _("Add New Playlist"));
 #endif
 
-    alignment2 = gtk_alignment_new(0.5, 0.5, 0, 0);
-    gtk_widget_show(alignment2);
-    gtk_container_add(GTK_CONTAINER(button_Add_Playlist), alignment2);
+    //    alignment2 = gtk_alignment_new(0.5, 0.5, 0, 0);
+    //    gtk_widget_show(alignment2);
+    //    gtk_container_add(GTK_CONTAINER(button_Add_Playlist), alignment2);
 #if HAVE_GTK3 == 0
     hbox3 = gtk_hbox_new(FALSE, 2);
 #else
     hbox3 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 2);
 #endif
     gtk_widget_show(hbox3);
-    gtk_container_add(GTK_CONTAINER(alignment2), hbox3);
+    gtk_container_add(GTK_CONTAINER(button_Add_Playlist), hbox3);
 #if HAVE_GTK3 == 0
     image2 = gtk_image_new_from_stock(GTK_STOCK_ADD, GTK_ICON_SIZE_BUTTON);
 #else 
@@ -203,9 +187,9 @@ GtkWidget* create_windowPlaylist(void) {
     gtk_widget_set_tooltip_text(button_Del_Playlist, _("Remove Current Selected Playlist"));
 #endif
 
-    alignment1 = gtk_alignment_new(0.5, 0.5, 0, 0);
-    gtk_widget_show(alignment1);
-    gtk_container_add(GTK_CONTAINER(button_Del_Playlist), alignment1);
+    //    alignment1 = gtk_alignment_new(0.5, 0.5, 0, 0);
+    //    gtk_widget_show(alignment1);
+    //    gtk_container_add(GTK_CONTAINER(button_Del_Playlist), alignment1);
 #if HAVE_GTK3 == 0
     hbox2 = gtk_hbox_new(FALSE, 2);
 #else
@@ -213,7 +197,7 @@ GtkWidget* create_windowPlaylist(void) {
 #endif
 
     gtk_widget_show(hbox2);
-    gtk_container_add(GTK_CONTAINER(alignment1), hbox2);
+    gtk_container_add(GTK_CONTAINER(button_Del_Playlist), hbox2);
 #if HAVE_GTK3 == 0
     image1 = gtk_image_new_from_stock(GTK_STOCK_DELETE, GTK_ICON_SIZE_BUTTON);
 #else
@@ -305,16 +289,16 @@ GtkWidget* create_windowPlaylist(void) {
     gtk_widget_set_tooltip_text(button_Add_Files, _("Add file to playlist"));
 #endif
 
-    alignment6 = gtk_alignment_new(0.5, 0.5, 0, 0);
-    gtk_widget_show(alignment6);
-    gtk_container_add(GTK_CONTAINER(button_Add_Files), alignment6);
+    //    alignment6 = gtk_alignment_new(0.5, 0.5, 0, 0);
+    //    gtk_widget_show(alignment6);
+    //    gtk_container_add(GTK_CONTAINER(button_Add_Files), alignment6);
 #if HAVE_GTK3 == 0
     hbox8 = gtk_hbox_new(FALSE, 2);
 #else
     hbox8 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 2);
 #endif
     gtk_widget_show(hbox8);
-    gtk_container_add(GTK_CONTAINER(alignment6), hbox8);
+    gtk_container_add(GTK_CONTAINER(button_Add_Files), hbox8);
 #if HAVE_GTK3 == 0
     image6 = gtk_image_new_from_stock(GTK_STOCK_GO_FORWARD, GTK_ICON_SIZE_BUTTON);
 #else
@@ -336,16 +320,16 @@ GtkWidget* create_windowPlaylist(void) {
     gtk_widget_set_tooltip_text(button_Del_File, _("Remove file from playlist"));
 #endif
 
-    alignment7 = gtk_alignment_new(0.5, 0.5, 0, 0);
-    gtk_widget_show(alignment7);
-    gtk_container_add(GTK_CONTAINER(button_Del_File), alignment7);
+    //    alignment7 = gtk_alignment_new(0.5, 0.5, 0, 0);
+    //    gtk_widget_show(alignment7);
+    //    gtk_container_add(GTK_CONTAINER(button_Del_File), alignment7);
 #if HAVE_GTK3 == 0
     hbox9 = gtk_hbox_new(FALSE, 2);
 #else
     hbox9 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 2);
 #endif
     gtk_widget_show(hbox9);
-    gtk_container_add(GTK_CONTAINER(alignment7), hbox9);
+    gtk_container_add(GTK_CONTAINER(button_Del_File), hbox9);
 #if HAVE_GTK3 == 0
     image7 = gtk_image_new_from_stock(GTK_STOCK_GO_BACK, GTK_ICON_SIZE_BUTTON);
 #else
@@ -487,24 +471,17 @@ GtkWidget* create_windowPlaylist(void) {
 
 // ************************************************************************************************
 
-/**
- * Callback to hanlde the Playlist menu/toolbar operations.
- * @param menuitem
- * @param user_data
- */
-void on_editPlaylist_activate(GtkMenuItem *menuitem, gpointer user_data) {
+void on_editPlaylist_activate(GtkWidget *item, gpointer user_data) {
+    UNUSED(item);
+    UNUSED(user_data);
     displayPlaylistDialog();
 } // end on_editPlaylist_activate()
 
-
 // ************************************************************************************************
 
-/**
- * Callback to handle adding file to playlist.
- * @param menuitem
- * @param user_data
- */
-void on_fileAddToPlaylist_activate(GtkMenuItem *menuitem, gpointer user_data) {
+void on_fileAddToPlaylist_activate(GtkWidget *item, gpointer user_data) {
+    UNUSED(item);
+    UNUSED(user_data);
     // Let's check to see if we have anything selected in our treeview?
     if (fileListGetSelection() == NULL) {
         displayInformation(_("No files/folders selected?"));
@@ -519,15 +496,11 @@ void on_fileAddToPlaylist_activate(GtkMenuItem *menuitem, gpointer user_data) {
     }
 }
 
-
 // ************************************************************************************************
 
-/**
- * Callback to handle removing file from playlist.
- * @param menuitem
- * @param user_data
- */
-void on_fileRemoveFromPlaylist_activate(GtkMenuItem *menuitem, gpointer user_data) {
+void on_fileRemoveFromPlaylist_activate(GtkWidget *item, gpointer user_data) {
+    UNUSED(item);
+    UNUSED(user_data);
     // Let's check to see if we have anything selected in our treeview?
     if (fileListGetSelection() == NULL) {
         displayInformation(_("No files/folders selected?"));
@@ -544,12 +517,6 @@ void on_fileRemoveFromPlaylist_activate(GtkMenuItem *menuitem, gpointer user_dat
 
 // ************************************************************************************************
 
-/**
- * Remove a list of files to the nominated playlist.
- * @param List
- * @param PlaylistID
- * @return
- */
 gboolean fileListRemoveFromPlaylist(GList *List, uint32_t PlaylistID) {
     LIBMTP_playlist_t *playlist = NULL;
     LIBMTP_playlist_t *node = NULL;
@@ -569,21 +536,14 @@ gboolean fileListRemoveFromPlaylist(GList *List, uint32_t PlaylistID) {
     return TRUE;
 }
 
-
 // ************************************************************************************************
 
-/**
- * Helper to add a single row to playlist.
- * @param Row
- * @param playlist
- */
 void __fileAddToPlaylist(GtkTreeRowReference *Row, LIBMTP_playlist_t **playlist) {
     GtkTreePath *path;
     GtkTreeIter iter;
     uint32_t objectID;
     gboolean isFolder;
     LIBMTP_track_t *tracks = deviceTracks;
-    LIBMTP_track_t *node = NULL;
     // convert the referenece to a path and retrieve the iterator;
     path = gtk_tree_row_reference_get_path(Row);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(fileList), &iter, path);
@@ -591,6 +551,7 @@ void __fileAddToPlaylist(GtkTreeRowReference *Row, LIBMTP_playlist_t **playlist)
     gtk_tree_model_get(GTK_TREE_MODEL(fileList), &iter, COL_ISFOLDER, &isFolder, COL_FILEID, &objectID, -1);
     if (isFolder == FALSE) {
         // Now add the file to the playlist.
+         LIBMTP_track_t *node = NULL;
         // We need the playlist pointer, and the **track** pointer;
         while (tracks != NULL) {
             if (tracks->item_id == objectID) {
@@ -604,23 +565,18 @@ void __fileAddToPlaylist(GtkTreeRowReference *Row, LIBMTP_playlist_t **playlist)
             playlistAddTrack(*(playlist), node);
         }
     }
+    gtk_tree_path_free(path);
 }
 
-
 // ************************************************************************************************
 
-/**
- * Helper to remove a single row from a playlist.
- * @param Row
- * @param playlist
- */
 void __fileRemoveFromPlaylist(GtkTreeRowReference *Row, LIBMTP_playlist_t **playlist) {
     GtkTreePath *path;
     GtkTreeIter iter;
     uint32_t objectID;
     gboolean isFolder;
     LIBMTP_track_t *tracks = deviceTracks;
-    LIBMTP_track_t *node = NULL;
+    
     // convert the referenece to a path and retrieve the iterator;
     path = gtk_tree_row_reference_get_path(Row);
     gtk_tree_model_get_iter(GTK_TREE_MODEL(fileList), &iter, path);
@@ -628,6 +584,7 @@ void __fileRemoveFromPlaylist(GtkTreeRowReference *Row, LIBMTP_playlist_t **play
     gtk_tree_model_get(GTK_TREE_MODEL(fileList), &iter, COL_ISFOLDER, &isFolder, COL_FILEID, &objectID, -1);
     if (isFolder == FALSE) {
         // Now add the file to the playlist.
+        LIBMTP_track_t *node = NULL;
         // We need the playlist pointer, and the **track** pointer;
         while (tracks != NULL) {
             if (tracks->item_id == objectID) {
@@ -641,19 +598,16 @@ void __fileRemoveFromPlaylist(GtkTreeRowReference *Row, LIBMTP_playlist_t **play
             playlistRemoveTrack(*(playlist), node, MTP_PLAYLIST_FIRST_INSTANCE);
         }
     }
+    gtk_tree_path_free(path);
 }
 
-
 // ************************************************************************************************
 
-/**
- * Display the Playlist Editor.
- */
 void displayPlaylistDialog(void) {
     //LIBMTP_playlist_t* tmpplaylist;
     LIBMTP_track_t* tmptrack;
     GtkTreeIter rowIter;
-    gchar * tmp_string;
+    //gchar * tmp_string;
 
     if (windowPlaylistDialog != NULL) {
         gtk_widget_hide(windowPlaylistDialog);
@@ -676,7 +630,7 @@ void displayPlaylistDialog(void) {
         while (tmptrack != NULL) {
             if ((tmptrack->storage_id == DeviceMgr.devicestorage->id) && (LIBMTP_FILETYPE_IS_AUDIO(tmptrack->filetype))) {
                 gtk_list_store_append(GTK_LIST_STORE(playlist_TrackList), &rowIter);
-                tmp_string = g_strdup_printf("%d:%.2d", (int) ((tmptrack->duration / 1000) / 60), (int) ((tmptrack->duration / 1000) % 60));
+                gchar * tmp_string = g_strdup_printf("%d:%.2d", (int) ((tmptrack->duration / 1000) / 60), (int) ((tmptrack->duration / 1000) % 60));
                 gtk_list_store_set(GTK_LIST_STORE(playlist_TrackList), &rowIter, COL_ARTIST, tmptrack->artist, COL_ALBUM, tmptrack->album,
                         COL_TRACKID, tmptrack->item_id, COL_TRACKNAME, tmptrack->title, COL_TRACKDURATION, tmp_string, -1);
                 g_free(tmp_string);
@@ -691,10 +645,6 @@ void displayPlaylistDialog(void) {
 
 // ************************************************************************************************
 
-/**
- * Setup the display for the Playlist.
- * @param treeviewFiles
- */
 void setupTrackList(GtkTreeView *treeviewFiles) {
     GtkCellRenderer *renderer;
     GtkTreeViewColumn *column;
@@ -745,16 +695,10 @@ void setupTrackList(GtkTreeView *treeviewFiles) {
     gtk_tree_view_append_column(GTK_TREE_VIEW(treeviewFiles), column);
     gtk_tree_view_column_set_resizable(column, TRUE);
     gtk_tree_view_column_set_visible(column, TRUE);
-
-
 }
 
 // ************************************************************************************************
 
-/**
- * Setup the list of tracks in the current playlist.
- * @param treeviewFiles
- */
 void setup_PL_List(GtkTreeView *treeviewFiles) {
     GtkCellRenderer *renderer;
     GtkTreeViewColumn *column;
@@ -819,10 +763,6 @@ void setup_PL_List(GtkTreeView *treeviewFiles) {
 
 // ************************************************************************************************
 
-/**
- * Set the state of the buttons within the playlist editor.
- * @param state
- */
 void SetPlaylistButtonState(gboolean state) {
     gtk_widget_set_sensitive(GTK_WIDGET(button_Del_Playlist), state);
     gtk_widget_set_sensitive(GTK_WIDGET(button_Export_Playlist), state);
@@ -836,26 +776,23 @@ void SetPlaylistButtonState(gboolean state) {
 
 // ************************************************************************************************
 
-/**
- * Setup the Playlist selection Combo Box in the playlist editor.
- */
 void setPlayListComboBox(void) {
     LIBMTP_playlist_t* tmpplaylist = NULL;
-    
+
     // We need to remove all entries in the combo box before starting.
     // This is a little bit of a hack - but does work.
     runPlaylistHandler = FALSE; // disable the handler from running on the control.
     // For some reason the "changed" event is triggered on a remove_all operation.
 #if HAVE_GTK3 == 0
     //gtk_list_store_clear(GTK_LIST_STORE(gtk_combo_box_get_model(GTK_COMBO_BOX(comboboxentry_playlist))));
-    while(comboboxentry_playlist_entries-- > 0){
+    while (comboboxentry_playlist_entries-- > 0) {
         gtk_combo_box_remove_text(GTK_COMBO_BOX(comboboxentry_playlist), 0);
     }
 #else
     gtk_combo_box_text_remove_all(GTK_COMBO_BOX_TEXT(comboboxentry_playlist));
 #endif
     comboboxentry_playlist_entries = 0;
-    
+
     if (devicePlayLists != NULL) {
         // Populate the playlist dropdown box;
         //comboboxentry_playlist;
@@ -863,9 +800,10 @@ void setPlayListComboBox(void) {
         while (tmpplaylist != NULL) {
             if (tmpplaylist->storage_id == DeviceMgr.devicestorage->id) {
 #if HAVE_GTK3 == 0
-                gtk_combo_box_append_text(GTK_COMBO_BOX(comboboxentry_playlist), g_strdup(tmpplaylist->name));
+                gtk_combo_box_append_text(GTK_COMBO_BOX(comboboxentry_playlist), (tmpplaylist->name));
 #else
-                gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(comboboxentry_playlist), g_strdup(tmpplaylist->name));
+                //gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(comboboxentry_playlist), g_strdup(tmpplaylist->name));
+                gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(comboboxentry_playlist), (tmpplaylist->name));
 #endif
                 comboboxentry_playlist_entries++;
             }
@@ -892,10 +830,6 @@ void setPlayListComboBox(void) {
 
 // ************************************************************************************************
 
-/**
- * Setup the list of tracks in the current selected playlist.
- * @param PlayListID
- */
 void setPlaylistField(gint PlayListID) {
     // This function will populate the playlist_PL_List widget with the
     // details of the selected playlist.
@@ -939,13 +873,8 @@ void setPlaylistField(gint PlayListID) {
 
 // ************************************************************************************************
 
-/**
- * Display the New Playlist Dialog box.
- * @return The name of the new playlist.
- */
 gchar* displayPlaylistNewDialog(void) {
     GtkWidget *dialog, *hbox, *label, *textbox;
-    gchar* textfield;
 
     dialog = gtk_dialog_new_with_buttons(_("New Playlist"), GTK_WINDOW(windowMain),
             (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
@@ -955,6 +884,8 @@ gchar* displayPlaylistNewDialog(void) {
 
     gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
     gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
+    gtk_container_set_border_width(GTK_CONTAINER(dialog), 5);
+
 #if HAVE_GTK3 == 0
     hbox = gtk_hbox_new(FALSE, 5);
 #else 
@@ -981,7 +912,7 @@ gchar* displayPlaylistNewDialog(void) {
 
     gint result = gtk_dialog_run(GTK_DIALOG(dialog));
     if (result == GTK_RESPONSE_OK) {
-        textfield = g_strdup(gtk_entry_get_text(GTK_ENTRY(textbox)));
+        gchar* textfield = g_strdup(gtk_entry_get_text(GTK_ENTRY(textbox)));
         if (strlen(textfield) == 0) {
             // We have an emtpy string.
             gtk_widget_destroy(dialog);
@@ -998,14 +929,8 @@ gchar* displayPlaylistNewDialog(void) {
 
 // ************************************************************************************************
 
-/**
- * Get the list of selected tracks in the playlist editor.
- * @return
- */
 GList* playlist_PL_ListGetSelection() {
     GList *selectedFiles, *ptr;
-    GtkTreeRowReference *ref;
-    GtkTreeModel *model;
     // Lets clear up the old list.
     g_list_free(playlist_Selection_PL_RowReferences);
     playlist_Selection_PL_RowReferences = NULL;
@@ -1016,11 +941,11 @@ GList* playlist_PL_ListGetSelection() {
     }
     // So now we must convert each selection to a row reference and store it in a new GList variable
     // which we will return below.
-    model = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview_Playlist_Files));
+    GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview_Playlist_Files));
     selectedFiles = gtk_tree_selection_get_selected_rows(playlist_PL_Selection, &model);
     ptr = selectedFiles;
     while (ptr != NULL) {
-        ref = gtk_tree_row_reference_new(GTK_TREE_MODEL(playlist_PL_List), (GtkTreePath*) ptr->data);
+        GtkTreeRowReference *ref = gtk_tree_row_reference_new(GTK_TREE_MODEL(playlist_PL_List), (GtkTreePath*) ptr->data);
         playlist_Selection_PL_RowReferences = g_list_append(playlist_Selection_PL_RowReferences, gtk_tree_row_reference_copy(ref));
         gtk_tree_row_reference_free(ref);
         ptr = ptr->next;
@@ -1032,10 +957,6 @@ GList* playlist_PL_ListGetSelection() {
 
 // ************************************************************************************************
 
-/**
- * Clear the selection of tracks in the playlist.
- * @return
- */
 gboolean playlist_PL_ListClearSelection() {
     if (playlist_PL_Selection != NULL)
         gtk_tree_selection_unselect_all(playlist_PL_Selection);
@@ -1044,11 +965,6 @@ gboolean playlist_PL_ListClearSelection() {
 
 // ************************************************************************************************
 
-/**
- * Remove the selected tracks from the playlist.
- * @param List
- * @return
- */
 gboolean playlist_PL_ListRemove(GList *List) {
     GtkTreeIter iter;
     gint tracknumber = 1;
@@ -1070,10 +986,6 @@ gboolean playlist_PL_ListRemove(GList *List) {
 
 // ************************************************************************************************
 
-/**
- * Remove the track from the current playlist.
- * @param Row
- */
 void __playlist_PL_Remove(GtkTreeRowReference *Row) {
     GtkTreePath *path;
     GtkTreeIter iter;
@@ -1083,18 +995,13 @@ void __playlist_PL_Remove(GtkTreeRowReference *Row) {
     // We have our Iter now.
     gtk_list_store_remove(GTK_LIST_STORE(playlist_PL_List), &iter);
     playlist_track_count--;
+    gtk_tree_path_free(path);
 }
 
 // ************************************************************************************************
 
-/**
- * Get the selection of tracks in the current playlist.
- * @return
- */
 GList* playlist_TrackList_GetSelection() {
     GList *selectedFiles, *ptr;
-    GtkTreeRowReference *ref;
-    GtkTreeModel *model;
     // Lets clear up the old list.
     g_list_free(playlist_Selection_TrackRowReferences);
     playlist_Selection_TrackRowReferences = NULL;
@@ -1105,11 +1012,11 @@ GList* playlist_TrackList_GetSelection() {
     }
     // So now we must convert each selection to a row reference and store it in a new GList variable
     // which we will return below.
-    model = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview_Avail_Files));
+    GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview_Avail_Files));
     selectedFiles = gtk_tree_selection_get_selected_rows(playlist_TrackSelection, &model);
     ptr = selectedFiles;
     while (ptr != NULL) {
-        ref = gtk_tree_row_reference_new(GTK_TREE_MODEL(playlist_TrackList), (GtkTreePath*) ptr->data);
+        GtkTreeRowReference *ref = gtk_tree_row_reference_new(GTK_TREE_MODEL(playlist_TrackList), (GtkTreePath*) ptr->data);
         playlist_Selection_TrackRowReferences = g_list_append(playlist_Selection_TrackRowReferences, gtk_tree_row_reference_copy(ref));
         gtk_tree_row_reference_free(ref);
         ptr = ptr->next;
@@ -1121,11 +1028,6 @@ GList* playlist_TrackList_GetSelection() {
 
 // ************************************************************************************************
 
-/**
- * Add the list of tracks to the selected playlist.
- * @param List
- * @return
- */
 gboolean playlist_TrackList_Add(GList *List) {
     g_list_foreach(List, (GFunc) __playlist_TrackList_Add, NULL);
     return TRUE;
@@ -1133,10 +1035,6 @@ gboolean playlist_TrackList_Add(GList *List) {
 
 // ************************************************************************************************
 
-/**
- * Add the individual track to the playlist.
- * @param Row
- */
 void __playlist_TrackList_Add(GtkTreeRowReference *Row) {
     GtkTreePath *path = NULL;
     GtkTreeIter iter;
@@ -1164,15 +1062,11 @@ void __playlist_TrackList_Add(GtkTreeRowReference *Row) {
     g_free(album);
     g_free(title);
     g_free(duration);
+    gtk_tree_path_free(path);
 }
 
 // ************************************************************************************************
 
-/**
- * Reorder the tracks within the playlist.
- * @param direction
- * @return
- */
 gboolean playlist_move_files(gint direction) {
     GList * playlist_files = NULL;
     GtkTreeIter iter;
@@ -1203,10 +1097,6 @@ gboolean playlist_move_files(gint direction) {
 
 // ************************************************************************************************
 
-/**
- * Move the selected track up in the playlist.
- * @param Row
- */
 void __playlist_move_files_up(GtkTreeRowReference *Row) {
     GtkTreePath *path;
     GtkTreeIter iter;
@@ -1221,15 +1111,11 @@ void __playlist_move_files_up(GtkTreeRowReference *Row) {
         gtk_tree_model_get_iter(GTK_TREE_MODEL(playlist_PL_List), &iter2, path);
         gtk_list_store_swap(GTK_LIST_STORE(playlist_PL_List), &iter, &iter2);
     }
-
+    gtk_tree_path_free(path);
 }
 
 // ************************************************************************************************
 
-/**
- * Move the selected track down in the playlist.
- * @param Row
- */
 void __playlist_move_files_down(GtkTreeRowReference *Row) {
     GtkTreePath *path;
     GtkTreeIter iter;
@@ -1243,14 +1129,11 @@ void __playlist_move_files_down(GtkTreeRowReference *Row) {
         // we have something to swap with...
         gtk_list_store_swap(GTK_LIST_STORE(playlist_PL_List), &iter, &iter2);
     }
+    gtk_tree_path_free(path);
 }
 
 // ************************************************************************************************
 
-/**
- * Save the current selected playlist to the device.
- * @param PlayListID
- */
 void playlist_SavePlaylist(gint PlayListID) {
     LIBMTP_playlist_t* tmpplaylist = devicePlayLists;
     gint tmpplaylistID = PlayListID;
@@ -1300,16 +1183,12 @@ void playlist_SavePlaylist(gint PlayListID) {
     devicePlayLists = getPlaylists();
 }
 
-
 // Playlist Callbacks.
 // ************************************************************************************************
 
-/**
- * Callback to handle closing the Playlist editor dialog.
- * @param menuitem
- * @param user_data
- */
-void on_quitPlaylist_activate(GtkMenuItem *menuitem, gpointer user_data) {
+void on_quitPlaylist_activate(GtkWidget *item, gpointer user_data) {
+    UNUSED(item);
+    UNUSED(user_data);
     // Save our current selected playlist!
     if (devicePlayLists != NULL)
         playlist_SavePlaylist(playlist_number);
@@ -1323,20 +1202,15 @@ void on_quitPlaylist_activate(GtkMenuItem *menuitem, gpointer user_data) {
 
 // ************************************************************************************************
 
-/**
- * Callback to handle the new Playlist button in the Playlist editor dialog.
- * @param menuitem
- * @param user_data
- */
-void on_Playlist_NewPlaylistButton_activate(GtkMenuItem *menuitem, gpointer user_data) {
-    //g_printf("Clicked on new playlist button\n");
-    gchar *playlistname = NULL;
+void on_Playlist_NewPlaylistButton_activate(GtkWidget *item, gpointer user_data) {
+    UNUSED(item);
+    UNUSED(user_data);
 
     // Save our current selected playlist!
     if (devicePlayLists != NULL)
         playlist_SavePlaylist(playlist_number);
 
-    playlistname = displayPlaylistNewDialog();
+    gchar *playlistname = displayPlaylistNewDialog();
     if (playlistname != NULL) {
         // Add in playlist to MTP device.
         playlistAdd(playlistname);
@@ -1346,9 +1220,9 @@ void on_Playlist_NewPlaylistButton_activate(GtkMenuItem *menuitem, gpointer user
         // Add it to our combobox
 
 #if HAVE_GTK3 == 0
-        gtk_combo_box_append_text(GTK_COMBO_BOX(comboboxentry_playlist), g_strdup(playlistname));
+        gtk_combo_box_append_text(GTK_COMBO_BOX(comboboxentry_playlist), (playlistname));
 #else
-        gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(comboboxentry_playlist), g_strdup(playlistname));
+        gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(comboboxentry_playlist), (playlistname));
 #endif
         g_free(playlistname);
 
@@ -1363,15 +1237,10 @@ void on_Playlist_NewPlaylistButton_activate(GtkMenuItem *menuitem, gpointer user
 
 // ************************************************************************************************
 
-/**
- * Callback to handle the Import Playlist button in the Playlist editor dialog.
- * @param menuitem
- * @param user_data
- */
-void on_Playlist_ImportPlaylistButton_activate(GtkMenuItem *menuitem, gpointer user_data) {
-    //g_printf("Clicked on new playlist button\n");
+void on_Playlist_ImportPlaylistButton_activate(GtkWidget *item, gpointer user_data) {
+    UNUSED(item);
+    UNUSED(user_data);
     gchar *playlistfilename = NULL;
-    gchar *playlistname = NULL;
     GtkWidget *FileDialog;
     GtkFileFilter *OpenFormFilter, *OpenFormFilter2;
 
@@ -1405,7 +1274,7 @@ void on_Playlist_ImportPlaylistButton_activate(GtkMenuItem *menuitem, gpointer u
 
     if (playlistfilename != NULL) {
         // Add in playlist to MTP device.
-        playlistname = playlistImport(playlistfilename);
+        gchar *playlistname = playlistImport(playlistfilename);
 
         // If our name is NULL, then the import failed...
         if (playlistname != NULL) {
@@ -1415,9 +1284,9 @@ void on_Playlist_ImportPlaylistButton_activate(GtkMenuItem *menuitem, gpointer u
             // Add it to our combobox
 
 #if HAVE_GTK3 == 0
-            gtk_combo_box_append_text(GTK_COMBO_BOX(comboboxentry_playlist), g_strdup(playlistname));
+            gtk_combo_box_append_text(GTK_COMBO_BOX(comboboxentry_playlist), (playlistname));
 #else
-            gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(comboboxentry_playlist), g_strdup(playlistname));
+            gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(comboboxentry_playlist), (playlistname));
 #endif
 
             // Set the active combobox item.
@@ -1441,14 +1310,9 @@ void on_Playlist_ImportPlaylistButton_activate(GtkMenuItem *menuitem, gpointer u
 
 // ************************************************************************************************
 
-/**
- * Callback to handle the Export Playlist button in the Playlist editor dialog.
- * @param menuitem
- * @param user_data
- */
-void on_Playlist_ExportPlaylistButton_activate(GtkMenuItem *menuitem, gpointer user_data) {
-    gchar *playlistfilename = NULL;
-    GtkWidget *FileDialog;
+void on_Playlist_ExportPlaylistButton_activate(GtkWidget *item, gpointer user_data) {
+    UNUSED(item);
+    UNUSED(user_data);
 
     // Save our current selected playlist!
     if (devicePlayLists != NULL)
@@ -1466,9 +1330,9 @@ void on_Playlist_ExportPlaylistButton_activate(GtkMenuItem *menuitem, gpointer u
         }
         // We should be in the correct playlist LIBMTP structure.
 
-        playlistfilename = g_strdup_printf("%s.%s", tmpplaylist->name, "m3u");
+        gchar *playlistfilename = g_strdup_printf("%s.%s", tmpplaylist->name, "m3u");
 
-        FileDialog = gtk_file_chooser_dialog_new(_("Save as..."),
+        GtkWidget *FileDialog = gtk_file_chooser_dialog_new(_("Save as..."),
                 GTK_WINDOW(windowMain), GTK_FILE_CHOOSER_ACTION_SAVE,
                 _("_Cancel"), GTK_RESPONSE_CANCEL,
                 _("_Open"), GTK_RESPONSE_ACCEPT,
@@ -1491,12 +1355,9 @@ void on_Playlist_ExportPlaylistButton_activate(GtkMenuItem *menuitem, gpointer u
 
 // ************************************************************************************************
 
-/**
- * Callback to handle the Delete Playlist button in the Playlist editor dialog.
- * @param menuitem
- * @param user_data
- */
-void on_Playlist_DelPlaylistButton_activate(GtkMenuItem *menuitem, gpointer user_data) {
+void on_Playlist_DelPlaylistButton_activate(GtkWidget *item, gpointer user_data) {
+    UNUSED(item);
+    UNUSED(user_data);
     gint PlayListID = gtk_combo_box_get_active(GTK_COMBO_BOX(comboboxentry_playlist));
     if (PlayListID != -1) {
         // We have something selected so lets do the dance.
@@ -1518,12 +1379,9 @@ void on_Playlist_DelPlaylistButton_activate(GtkMenuItem *menuitem, gpointer user
 
 // ************************************************************************************************
 
-/**
- * Callback to handle the Delete Track button in the Playlist editor dialog.
- * @param menuitem
- * @param user_data
- */
-void on_Playlist_DelFileButton_activate(GtkMenuItem *menuitem, gpointer user_data) {
+void on_Playlist_DelFileButton_activate(GtkWidget *item, gpointer user_data) {
+    UNUSED(item);
+    UNUSED(user_data);
     if (playlist_PL_ListGetSelection() == NULL)
         return;
     playlist_PL_ListRemove(playlist_PL_ListGetSelection());
@@ -1531,12 +1389,9 @@ void on_Playlist_DelFileButton_activate(GtkMenuItem *menuitem, gpointer user_dat
 
 // ************************************************************************************************
 
-/**
- * Callback to handle the Add Track button in the Playlist editor dialog.
- * @param menuitem
- * @param user_data
- */
-void on_Playlist_AddFileButton_activate(GtkMenuItem *menuitem, gpointer user_data) {
+void on_Playlist_AddFileButton_activate(GtkWidget *item, gpointer user_data) {
+    UNUSED(item);
+    UNUSED(user_data);
     //g_printf("Clicked on add file in playlist button\n");
     if (playlist_TrackList_GetSelection() == NULL)
         return;
@@ -1545,35 +1400,26 @@ void on_Playlist_AddFileButton_activate(GtkMenuItem *menuitem, gpointer user_dat
 
 // ************************************************************************************************
 
-/**
- * Callback to handle the Move Track Up button in the Playlist editor dialog.
- * @param menuitem
- * @param user_data
- */
-void on_Playlist_FileUpButton_activate(GtkMenuItem *menuitem, gpointer user_data) {
+void on_Playlist_FileUpButton_activate(GtkWidget *item, gpointer user_data) {
+    UNUSED(item);
+    UNUSED(user_data);
     playlist_move_files(-1);
 } // end on_Playlist_FileUpButton_activate()
 
 // ************************************************************************************************
 
-/**
- * Callback to handle the Move Track Down button in the Playlist editor dialog.
- * @param menuitem
- * @param user_data
- */
-void on_Playlist_FileDownButton_activate(GtkMenuItem *menuitem, gpointer user_data) {
+void on_Playlist_FileDownButton_activate(GtkWidget *item, gpointer user_data) {
+    UNUSED(item);
+    UNUSED(user_data);
     playlist_move_files(1);
 } // end on_Playlist_FileDownButton_activate()
 
 // ************************************************************************************************
 
-/**
- * Callback to handle the change of Playlist selection in the Playlist editor dialog.
- * @param menuitem
- * @param user_data
- */
 void on_Playlist_Combobox_activate(GtkComboBox *combobox, gpointer user_data) {
-    if(runPlaylistHandler == TRUE){
+    UNUSED(combobox);
+    UNUSED(user_data);
+    if (runPlaylistHandler == TRUE) {
         // Save our current selected playlist
         playlist_SavePlaylist(playlist_number);
         // Get our new playlist ID, and display the contents of it.
